/**
 * Copyright (c) 2007, 2020 Borland Software Corporation, CEA LIST, Artal and others
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *    Alexander Shatalin (Borland) - initial API and implementation
 *    Michael Golubev (Montages) - #386838 - migrate to Xtend2
 *    Aurelien Didier (ARTAL) - aurelien.didier51@gmail.com - Bug 569174
 *    Etienne Allogo (ARTAL) - etienne.allogo@artal.fr - Bug 569174 : L1.2 clean up
 */
package xpt.navigator;

import com.google.inject.Inject;
import com.google.inject.Singleton;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenApplication;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenDiagram;
import org.eclipse.papyrus.gmf.codegen.gmfgen.GenEditorGenerator;
import org.eclipse.xtend2.lib.StringConcatenation;
import org.eclipse.xtext.xbase.lib.Extension;
import xpt.Common;

@Singleton
@SuppressWarnings("all")
public class getEditorInput {
  @Inject
  @Extension
  private Common _common;

  public CharSequence getEditorInput(final GenEditorGenerator it) {
    StringConcatenation _builder = new StringConcatenation();
    CharSequence _generatedMemberComment = this._common.generatedMemberComment();
    _builder.append(_generatedMemberComment);
    _builder.newLineIfNotEmpty();
    _builder.append("private static org.eclipse.ui.IEditorInput getEditorInput(org.eclipse.gmf.runtime.notation.Diagram diagram) {");
    _builder.newLine();
    _builder.append("\t");
    _builder.append("org.eclipse.emf.ecore.resource.Resource diagramResource = diagram.eResource();");
    _builder.newLine();
    {
      GenApplication _application = it.getApplication();
      boolean _tripleEquals = (null == _application);
      if (_tripleEquals) {
        _builder.append("for (org.eclipse.emf.ecore.EObject nextEObject : diagramResource.getContents()) {");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("if (nextEObject == diagram) {");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("return new org.eclipse.ui.part.FileEditorInput(org.eclipse.emf.workspace.util.WorkspaceSynchronizer.getFile(diagramResource));");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("}");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("if (nextEObject instanceof org.eclipse.gmf.runtime.notation.Diagram) {");
        _builder.newLine();
        _builder.append("\t\t");
        _builder.append("break;");
        _builder.newLine();
        _builder.append("\t");
        _builder.append("}");
        _builder.newLine();
        _builder.append("}");
        _builder.newLine();
      }
    }
    _builder.append("\t");
    CharSequence _defineURIEditorInput = this.defineURIEditorInput(it.getDiagram(), "diagram", "editorInput");
    _builder.append(_defineURIEditorInput, "\t");
    _builder.newLineIfNotEmpty();
    _builder.append("\t");
    _builder.append("return editorInput;");
    _builder.newLine();
    _builder.append("}");
    _builder.newLine();
    return _builder;
  }

  public CharSequence defineURIEditorInput(final GenDiagram it, final String diagramVarName, final String editorInputVarName) {
    StringConcatenation _builder = new StringConcatenation();
    _builder.append("org.eclipse.emf.common.util.URI uri = org.eclipse.emf.ecore.util.EcoreUtil.getURI(");
    _builder.append(diagramVarName);
    _builder.append(");");
    _builder.newLineIfNotEmpty();
    _builder.append("String editorName = uri.lastSegment() + \'#\' + ");
    _builder.append(diagramVarName);
    _builder.append(".eResource().getContents().indexOf(");
    _builder.append(diagramVarName);
    _builder.append(");");
    _builder.newLineIfNotEmpty();
    _builder.append("org.eclipse.ui.IEditorInput ");
    _builder.append(editorInputVarName);
    _builder.append(" = new org.eclipse.emf.common.ui.URIEditorInput(uri, editorName);");
    _builder.newLineIfNotEmpty();
    return _builder;
  }
}
